@@ -3,7 +3,7 @@
   Copyright (C) 2000  Ales Cepek <cepek@fsv.cvut.cz>,
                 2001  Ales Cepek <cepek@fsv.cvut.cz>,
                       Jan Pytel  <pytel@gama.fsv.cvut.cz>
-                2011, 2014, 2018  Ales Cepek <cepek@gnu.org>
+                2011, 2014, 2018, 2019  Ales Cepek <cepek@gnu.org>
 
   GNU Gama is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 
 #include <string>
 #include <cstddef>
+#include <functional>
 
 namespace GNU_gama { namespace local
 {
@@ -62,4 +63,14 @@ namespace GNU_gama { namespace local
 
 }}      // namespace GNU_gama::local
 
+
+namespace std
+{
+  template<>
+  struct hash<GNU_gama::local::PointID>
+  {
+    size_t operator()(const GNU_gama::local::PointID & obj) const;
+  };
+}
+
 #endif
