@@ -161,8 +161,7 @@ try
            "<parameters  sigma-apr = '" << sigma_apr_ << "'\n"
            "             conf-pr = '" << conf_pr_<< "'\n"
            "             tol-abs = '" << tol_abs_ << "'\n"
-           "             sigma-act = 'aposteriori'\n"
-           "             update-constrained-coordinates = 'yes'/>\n\n"
+           "             sigma-act = 'aposteriori' />\n\n"
            "<points-observations distance-stdev='" << distance_stdev_ << "'\n"
            "                     direction-stdev='" << direction_stdev_ << "'\n"
            "                     angle-stdev='" << angle_stdev_ << "'\n"
